( cd usr/bin ; rm -rf epic )
( cd usr/bin ; ln -sf /usr/bin/epic-EPIC4-1.0 epic )
( cd usr/bin ; rm -rf epic.old )
( cd usr/bin ; ln -sf /usr/bin/epic-EPIC4-1.0 epic.old )
( cd usr/share/epic/help/1_General ; rm -rf exit )
( cd usr/share/epic/help/1_General ; ln -sf quit exit )
( cd usr/share/epic/help/1_General ; rm -rf leave )
( cd usr/share/epic/help/1_General ; ln -sf part leave )
( cd usr/share/epic/help/1_General ; rm -rf signoff )
( cd usr/share/epic/help/1_General ; ln -sf quit signoff )
( cd usr/share/epic/help/2_Queries ; rm -rf date )
( cd usr/share/epic/help/2_Queries ; ln -sf time date )
( cd usr/share/epic/help/2_Queries ; rm -rf host )
( cd usr/share/epic/help/2_Queries ; ln -sf userhost host )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta10_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta10_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta11_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta11_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta12_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta12_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta13_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta13_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta14_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta14_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta15_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta15_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta16_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta16_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta17_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta17_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta18_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta18_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta19_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta19_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta20_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta20_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta21_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta21_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta22_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta22_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta23_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta23_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta24_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta24_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta25_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta25_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta26_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta26_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta27_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta27_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta28_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta28_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta29_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta29_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta2_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta2_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta30_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta30_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta31_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta31_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta32_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta32_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta33_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta33_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta34_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta34_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta35_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta35_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta36_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta36_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta37_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta37_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta38_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta38_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta39_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta39_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta3_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta3_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta5_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta5_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta6_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta6_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta7_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta7_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta8_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta8_character )
( cd usr/share/epic/help/4_Misc/bind ; rm -rf meta9_character )
( cd usr/share/epic/help/4_Misc/bind ; ln -sf meta1_character meta9_character )
( cd usr/share/epic/help/4_Misc ; rm -rf irchost )
( cd usr/share/epic/help/4_Misc ; ln -sf hostname irchost )
( cd usr/share/epic/help/4_Misc ; rm -rf ircname )
( cd usr/share/epic/help/4_Misc ; ln -sf realname ircname )
( cd usr/share/epic/help/4_Misc/set ; rm -rf status_format1 )
( cd usr/share/epic/help/4_Misc/set ; ln -sf status_format status_format1 )
( cd usr/share/epic/help/4_Misc/set ; rm -rf status_format2 )
( cd usr/share/epic/help/4_Misc/set ; ln -sf status_format status_format2 )
( cd usr/share/epic/help/4_Misc/set ; rm -rf status_user1 )
( cd usr/share/epic/help/4_Misc/set ; ln -sf status_user status_user1 )
( cd usr/share/epic/help/4_Misc/set ; rm -rf status_user2 )
( cd usr/share/epic/help/4_Misc/set ; ln -sf status_user status_user2 )
( cd usr/share/epic/help/4_Misc/set ; rm -rf status_user3 )
( cd usr/share/epic/help/4_Misc/set ; ln -sf status_user status_user3 )
( cd usr/share/epic/help/4_Misc/set ; rm -rf status_user4 )
( cd usr/share/epic/help/4_Misc/set ; ln -sf status_user status_user4 )
( cd usr/share/epic/help/4_Misc/set ; rm -rf status_user5 )
( cd usr/share/epic/help/4_Misc/set ; ln -sf status_user status_user5 )
( cd usr/share/epic/help/4_Misc/set ; rm -rf status_user6 )
( cd usr/share/epic/help/4_Misc/set ; ln -sf status_user status_user6 )
( cd usr/share/epic/help/4_Misc/set ; rm -rf status_user7 )
( cd usr/share/epic/help/4_Misc/set ; ln -sf status_user status_user7 )
( cd usr/share/epic/help/4_Misc/set ; rm -rf status_user8 )
( cd usr/share/epic/help/4_Misc/set ; ln -sf status_user status_user8 )
( cd usr/share/epic/help/4_Misc/set ; rm -rf status_user9 )
( cd usr/share/epic/help/4_Misc/set ; ln -sf status_user status_user9 )
( cd usr/share/epic/help/5_Programming ; rm -rf fec )
( cd usr/share/epic/help/5_Programming ; ln -sf fe fec )
( cd usr/share/epic/help/5_Programming ; rm -rf input_char )
( cd usr/share/epic/help/5_Programming ; ln -sf input input_char )
( cd usr/share/epic/help/5_Programming ; rm -rf pause )
( cd usr/share/epic/help/5_Programming ; ln -sf sleep pause )
( cd usr/share/epic/help/5_Programming ; rm -rf shift )
( cd usr/share/epic/help/5_Programming ; ln -sf unshift shift )
( cd usr/share/epic/help/5_Programming ; rm -rf unless )
( cd usr/share/epic/help/5_Programming ; ln -sf if unless )
( cd usr/share/epic/help/5_Programming ; rm -rf until )
( cd usr/share/epic/help/5_Programming ; ln -sf while until )
( cd usr/share/epic/help/6_Functions ; rm -rf before )
( cd usr/share/epic/help/6_Functions ; ln -sf after before )
( cd usr/share/epic/help/6_Functions ; rm -rf beforew )
( cd usr/share/epic/help/6_Functions ; ln -sf afterw beforew )
( cd usr/share/epic/help/6_Functions ; rm -rf chanusers )
( cd usr/share/epic/help/6_Functions ; ln -sf onchannel chanusers )
( cd usr/share/epic/help/6_Functions ; rm -rf chanwin )
( cd usr/share/epic/help/6_Functions ; ln -sf winchan chanwin )
( cd usr/share/epic/help/6_Functions ; rm -rf chr )
( cd usr/share/epic/help/6_Functions ; ln -sf ascii chr )
( cd usr/share/epic/help/6_Functions ; rm -rf diff )
( cd usr/share/epic/help/6_Functions ; ln -sf common diff )
( cd usr/share/epic/help/6_Functions ; rm -rf getrmatches )
( cd usr/share/epic/help/6_Functions ; ln -sf getmatches getrmatches )
( cd usr/share/epic/help/6_Functions ; rm -rf ifindfirst )
( cd usr/share/epic/help/6_Functions ; ln -sf finditem ifindfirst )
( cd usr/share/epic/help/6_Functions ; rm -rf igetitem )
( cd usr/share/epic/help/6_Functions ; ln -sf getitem igetitem )
( cd usr/share/epic/help/6_Functions ; rm -rf igetrmatches )
( cd usr/share/epic/help/6_Functions ; ln -sf igetmatches igetrmatches )
( cd usr/share/epic/help/6_Functions ; rm -rf nochops )
( cd usr/share/epic/help/6_Functions ; ln -sf chops nochops )
( cd usr/share/epic/help/6_Functions ; rm -rf notw )
( cd usr/share/epic/help/6_Functions ; ln -sf word notw )
( cd usr/share/epic/help/6_Functions ; rm -rf numsort )
( cd usr/share/epic/help/6_Functions ; ln -sf sort numsort )
( cd usr/share/epic/help/6_Functions ; rm -rf pass )
( cd usr/share/epic/help/6_Functions ; ln -sf strip pass )
( cd usr/share/epic/help/6_Functions ; rm -rf push )
( cd usr/share/epic/help/6_Functions ; ln -sf pop push )
( cd usr/share/epic/help/6_Functions ; rm -rf regcomp )
( cd usr/share/epic/help/6_Functions ; ln -sf regex regcomp )
( cd usr/share/epic/help/6_Functions ; rm -rf regerror )
( cd usr/share/epic/help/6_Functions ; ln -sf regex regerror )
( cd usr/share/epic/help/6_Functions ; rm -rf regexec )
( cd usr/share/epic/help/6_Functions ; ln -sf regex regexec )
( cd usr/share/epic/help/6_Functions ; rm -rf regfree )
( cd usr/share/epic/help/6_Functions ; ln -sf regex regfree )
( cd usr/share/epic/help/6_Functions ; rm -rf rfilter )
( cd usr/share/epic/help/6_Functions ; ln -sf filter rfilter )
( cd usr/share/epic/help/6_Functions ; rm -rf right )
( cd usr/share/epic/help/6_Functions ; ln -sf left right )
( cd usr/share/epic/help/6_Functions ; rm -rf rightw )
( cd usr/share/epic/help/6_Functions ; ln -sf leftw rightw )
( cd usr/share/epic/help/6_Functions ; rm -rf rindex )
( cd usr/share/epic/help/6_Functions ; ln -sf index rindex )
( cd usr/share/epic/help/6_Functions ; rm -rf rmatch )
( cd usr/share/epic/help/6_Functions ; ln -sf match rmatch )
( cd usr/share/epic/help/6_Functions ; rm -rf rmatchitem )
( cd usr/share/epic/help/6_Functions ; ln -sf matchitem rmatchitem )
( cd usr/share/epic/help/6_Functions ; rm -rf rpattern )
( cd usr/share/epic/help/6_Functions ; ln -sf pattern rpattern )
( cd usr/share/epic/help/6_Functions ; rm -rf tdiff2 )
( cd usr/share/epic/help/6_Functions ; ln -sf tdiff tdiff2 )
